@@ -147,6 +147,8 @@ define('_auth', {
   type: [null, String],
   description: `
     A basic-auth string to use when authenticating against the npm registry.
+    This will ONLY be used to authenticate against the npm registry.  For other
+    registries you will need to scope it like "//other-registry.tld/:_auth"
 
     Warning: This should generally not be set via a command-line option.  It
     is safer to use a registry-provided authentication bearer token stored in
@@ -1070,6 +1072,17 @@ define('init.version', {
   `,
 })
 
+define('install-links', {
+  default: false,
+  type: Boolean,
+  description: `
+    When set file: protocol dependencies that exist outside of the project root
+    will be packed and installed as regular dependencies instead of creating a
+    symlink. This option has no effect on workspaces.
+  `,
+  flatten,
+})
+
 define('json', {
   default: false,
   type: Boolean,
@@ -1372,6 +1385,18 @@ define('omit', {
   },
 })
 
+define('omit-lockfile-registry-resolved', {
+  default: false,
+  type: Boolean,
+  description: `
+    This option causes npm to create lock files without a \`resolved\` key for
+    registry dependencies. Subsequent installs will need to resolve tarball
+    endpoints with the configured registry, likely resulting in a longer install
+    time.
+  `,
+  flatten,
+})
+
 define('only', {
   default: null,
   type: [null, 'prod', 'production'],
@@ -1435,10 +1460,6 @@ define('package-lock', {
     This will also prevent _writing_ \`package-lock.json\` if \`save\` is
     true.
 
-    When package package-locks are disabled, automatic pruning of extraneous
-    modules will also be disabled.  To remove extraneous modules with
-    package-locks disabled use \`npm prune\`.
-
     This configuration does not affect \`npm ci\`.
   `,
   flatten: (key, obj, flatOptions) => {
@@ -1847,7 +1868,7 @@ define('searchexclude', {
   `,
   flatten (key, obj, flatOptions) {
     flatOptions.search = flatOptions.search || { limit: 20 }
-    flatOptions.search.exclude = obj[key]
+    flatOptions.search.exclude = obj[key].toLowerCase()
   },
 })
 
